Agent ROS Bridge Documentation
==============================

Welcome to the Agent ROS Bridge documentation.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   API_REFERENCE
   ARCHITECTURE_V2
   USER_MANUAL
   PHYSICAL_TESTING
   TDD_WORKFLOW
   CI_COMPLIANCE

API Documentation
-----------------

.. automodule:: agent_ros_bridge.gateway_v2.core
   :members:

.. automodule:: agent_ros_bridge.gateway_v2.connectors.ros2_connector
   :members:

.. automodule:: agent_ros_bridge.gateway_v2.connectors.ros1_connector
   :members:

.. automodule:: agent_ros_bridge.gateway_v2.transports.grpc_transport
   :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
